postgres.PostgresDocumentFactory

|  | ## Cheshire3 Object Model: Class PostgresDocumentFactory

Module postgres :: Class PostgresDocumentFactory

## Class PostgresDocumentFactory
source code

Object Tree:

                     object --+
                              |
          configParser.C3Object --+
                                  |
        baseObjects.DocumentFactory --+
                                      |
    documentFactory.BaseDocumentFactory --+
                                          |
                                         PostgresDocumentFactory

Instance Methods

__init__(self, session, config, parent)
Inherited from `documentFactory.BaseDocumentFactory`: `__iter__`, `get_document`, `load`, `next`, `register_stream` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

database |
host |
port |
Inherited from `documentFactory.BaseDocumentFactory`: `cache`, `codec`, `dataPath`, `docStream`, `format`, `generator`, `previousIdx`, `schema`, `streamHash` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
Overrides: documentFactory.BaseDocumentFactory.__init__

Class Variable Details

    ### database Value:
        ''

    ### host Value:
        ''

    ### port Value:
        0